@@ -11,11 +11,11 @@ Game::Planeshift::Info - A module to retrieve players' data on the main Planeshi
 
 =head1 VERSION
 
-Version 0.1
+Version 0.2b
 
 =cut
 
-our $VERSION = '0.1';
+our $VERSION = '0.2b';
 
 =head1 SYNOPSIS
 
@@ -43,6 +43,8 @@ B<encoding> : A string. The encoding you currently use (default: iso-8859-1)
 
 B<players> : An arrayref. The list of players you want to see the status.
 
+B<info_page> : A string. The URL of the page to parse to retrieve informations on the Planeshift server (default: http://laanx.fragnetics.com/index.php?page=char_stats)
+
 =cut
 
 sub new
@@ -75,7 +77,7 @@ On screen you will have :
 		'online_players' => {
 					'Caules' => 0,
 					'Narita' => 0,
-					'Javeroal' => 0,
+					'Javeroal' => 1,
 					'Setill' => 0,
 					'Baston' => 0,
 					'Soshise' => 0,
@@ -83,18 +85,30 @@ On screen you will have :
 					'Ehasara' => 0
 				},
 		'most_active_players' => {
-					'Javeroal' => '1960.31',
-					'Ganinos' => '1383.72',
-					'Proteous' => '1849.31',
+					'Javeroal' => '1963.53',
+					'Ganinos' => '1388.28',
+					'Proteous' => '1851.65',
 					'Ogu' => '1486.75',
-					'Verrliit' => '1545.64'
+					'Verrliit' => '1552.45'
 					},
+		'server_status' => {
+				'Time' => 'Sun Feb 26 15:31:57 SGT 2006',
+				'Total_Online' => 45,
+				'Accounts' => '197993',
+				'Report_Time_' => 'Sun Feb 26 15:31:56 SGT 2006',
+				'Cal3d_Date' => '2005-05-15 00:00:00',
+				'PS_Date' => '2006-01-14 00:00:00',
+				'CS_Date' => '2006-01-04 00:00:00',
+				'CEL_Date' => '2006-01-04 00:00:00',
+				'Characters' => '75687',
+				'Net_Version' => '0x47 '
+				},
 		'best_advisors' => {
-				'Wechafel' => '0',
-				'Greldolin' => '0',
-				'Carling' => '0',
-				'Nightelf' => '0',
-				'Yosir' => '0'
+				'Waoredo' => '3',
+				'Virtutes' => '4',
+				'Janner' => '18',
+				'Minuis' => '18',
+				'Gigelf' => '8'
 				},
 		'cleverer_players' => {
 					'Maximillian' => '127.00',
@@ -102,27 +116,27 @@ On screen you will have :
 					'Thinkundus' => '139.00',
 					'Marco' => '140.00',
 					'Lemethian' => '124.00'
-				},
+					},
 		'best_player_average' => {
 					'Anfa' => {
-							'hours_per_day' => '9.0277',
-							'day_active' => '62'
+							'hours_per_day' => '8.9571',
+							'day_active' => '63'
 						},
 					'Javeroal' => {
-							'hours_per_day' => '11.2662',
-							'day_active' => '174'
+							'hours_per_day' => '11.2202',
+							'day_active' => '175'
 							},
-					'Covirose' => {
-							'hours_per_day' => '8.7113',
-							'day_active' => '23'
+					'Setill' => {
+							'hours_per_day' => '8.5811',
+							'day_active' => '130'
 							},
 					'Tutoned' => {
-							'hours_per_day' => '8.8385',
-							'day_active' => '27'
+							'hours_per_day' => '8.5708',
+							'day_active' => '28'
 							},
 					'Satayne' => {
-							'hours_per_day' => '9.7779',
-							'day_active' => '127'
+							'hours_per_day' => '9.7551',
+							'day_active' => '128'
 							}
 					},
 		'stronger_players' => {
@@ -131,9 +145,9 @@ On screen you will have :
 					'Eolius' => '151.00',
 					'Rilno' => '150.00',
 					'Slimx' => '150.00'
-				},
+					},
 		'dueling_champs' => {
-					'Tarel' => '516.96',
+					'Tarel' => '516.23',
 					'Xshii' => '324.00',
 					'Xeohna' => '300.00',
 					'Brittany' => '263.33',
@@ -141,6 +155,7 @@ On screen you will have :
 				}
 		};
 
+
 NOTE: In the 'online_players' section you will find a hashref where keys are players' name and value a boolean (0 or 1). So obviously 0 is when player is not online and 1 when he is.
 
 NOTE2: The only information keep in mind by the object after a call to this method is the list off online players.
@@ -177,9 +192,12 @@ sub _parse_content
 	my ($self,$content) = @_;
 	my $data = {};
 	my @raw_data=split(/\n/,$content);
-	foreach (@{$self->{players}})
+	if(defined($self->{players}))
 	{
-		$data->{online_players}->{$_} = 0;
+		foreach (@{$self->{players}})
+		{
+			$data->{online_players}->{$_} = 0;
+		}
 	}
 	for (my $k=0;$k<=$#raw_data;$k++)
 	{
@@ -255,7 +273,7 @@ sub _parse_content
 				{
 					$start_found++;
 				}
-				if($raw_data[$k]=~/\s*<table border=0 cellspacing="0" cellpadding="1">/i)
+				if($raw_data[$k]=~/\s*<BR><BR>/i) #/\s*<table border=0 cellspacing="0" cellpadding="1">/i
 				{
 					last ;
 				}
@@ -263,17 +281,18 @@ sub _parse_content
 				$k++;
 			}
 # 			print "(active) \$k is now at $k/$#raw_data\n";
-# 			print "===> DEBUG (active) <===\n\n$html\n\n===> END DEBUG <===\n\n";
-			foreach (split(/<\/TR>/,$html))
+# 			print "===> DEBUG (online) <===\n\n$html\n\n===> END DEBUG <===\n\n";
+			foreach my $name (split(/,/,$html))
 			{
-				s/^\s*//g;
-				/<TR>(.+)$/;
-				if($1)
+				$name =~ s/\s*//g;
+				$name =~ s/<p>//ig;
+				if(defined($self->{players}) && exists($data->{online_players}->{$name}))
 				{
-					my $l = $1 ;
-					my ($name) = $l =~/<TD>([^<]+)<\/TD>/g ;
-					$data->{online_players}->{$name} = 1 if($name);
-# 					print "online status for $name is $data->{online_players}->{$name}\n";
+					$data->{online_players}->{$name} = 1 ;
+				}
+				elsif(!defined($self->{players}))
+				{
+					$data->{online_players}->{$name} = 1 ;
 				}
 			}
 			$self->{online_players} = $data->{online_players};
@@ -538,32 +557,33 @@ The XML generated by this method on the data previously retrieve is :
 	<?xml version="1.0" encoding="iso-8859-1" standalone="yes"?>
 	<planeshift-info>
 		<server-status>
-			<time>Sat Feb 25 22:30:57 SGT 2006</time>
-			<total-online>28</total-online>
-			<accounts>197554</accounts>
-			<report-time->Sat Feb 25 22:30:57 SGT 2006</report-time->
+			<time>Sun Feb 26 15:31:57 SGT 2006</time>
+			<total-online>45</total-online>
+			<accounts>197993</accounts>
+			<report-time->Sun Feb 26 15:31:56 SGT 2006</report-time->
 			<cal3d-date>2005-05-15 00:00:00</cal3d-date>
 			<ps-date>2006-01-14 00:00:00</ps-date>
 			<cs-date>2006-01-04 00:00:00</cs-date>
 			<cel-date>2006-01-04 00:00:00</cel-date>
-			<characters>75408</characters>
+			<characters>75687</characters>
 			<net-version>0x47 </net-version>
 		</server-status>
 		<online-players>
+			<player name="Javeroal" />
 		</online-players>
 		<most-active-players>
-			<player name="Javeroal" hours="1960.31"/>
-			<player name="Ganinos" hours="1383.72"/>
-			<player name="Proteous" hours="1849.31"/>
+			<player name="Javeroal" hours="1963.53"/>
+			<player name="Ganinos" hours="1388.28"/>
+			<player name="Proteous" hours="1851.65"/>
 			<player name="Ogu" hours="1486.75"/>
-			<player name="Verrliit" hours="1545.64"/>
+			<player name="Verrliit" hours="1552.45"/>
 		</most-active-players>
 		<best-advisors>
-			<player name="Lokizzle" points="0"/>
-			<player name="Kamarier" points="0"/>
-			<player name="Tfecw" points="0"/>
-			<player name="Hanarray" points="0"/>
-			<player name="Mannoth" points="0"/>
+			<player name="Waoredo" points="3"/>
+			<player name="Virtutes" points="4"/>
+			<player name="Janner" points="18"/>
+			<player name="Minuis" points="18"/>
+			<player name="Gigelf" points="8"/>
 		</best-advisors>
 		<cleverer-players>
 			<player name="Maximillian" intelligence="127.00"/>
@@ -573,11 +593,11 @@ The XML generated by this method on the data previously retrieve is :
 			<player name="Lemethian" intelligence="124.00"/>
 		</cleverer-players>
 		<best-player-average>
-			<player name="Anfa" hours-per-day="9.0277" day-active="62"/>
-			<player name="Javeroal" hours-per-day="11.2662" day-active="174"/>
-			<player name="Covirose" hours-per-day="8.7113" day-active="23"/>
-			<player name="Tutoned" hours-per-day="8.8385" day-active="27"/>
-			<player name="Satayne" hours-per-day="9.7779" day-active="127"/>
+			<player name="Anfa" hours-per-day="8.9571" day-active="63"/>
+			<player name="Javeroal" hours-per-day="11.2202" day-active="175"/>
+			<player name="Setill" hours-per-day="8.5811" day-active="130"/>
+			<player name="Tutoned" hours-per-day="8.5708" day-active="28"/>
+			<player name="Satayne" hours-per-day="9.7551" day-active="128"/>
 		</best-player-average>
 		<stronger-players>
 			<player name="Ozbi" strength="150.00"/>
@@ -587,7 +607,7 @@ The XML generated by this method on the data previously retrieve is :
 			<player name="Slimx" strength="150.00"/>
 		</stronger-players>
 		<dueling-champs>
-			<player name="Tarel" points="516.96"/>
+			<player name="Tarel" points="516.23"/>
 			<player name="Xshii" points="324.00"/>
 			<player name="Xeohna" points="300.00"/>
 			<player name="Brittany" points="263.33"/>
